//////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2016 Leszek Koltunski                                                          //
//                                                                                          //
// This file is part of Distorted.                                                          //
//                                                                                          //
// Distorted is free software: you can redistribute it and/or modify                        //
// it under the terms of the GNU General Public License as published by                     //
// the Free Software Foundation, either version 2 of the License, or                        //
// (at your option) any later version.                                                      //
//                                                                                          //
// Distorted is distributed in the hope that it will be useful,                             //
// but WITHOUT ANY WARRANTY; without even the implied warranty of                           //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                            //
// GNU General Public License for more details.                                             //
//                                                                                          //
// You should have received a copy of the GNU General Public License                        //
// along with Distorted.  If not, see <http://www.gnu.org/licenses/>.                       //
//////////////////////////////////////////////////////////////////////////////////////////////

varying vec2 vTexCoordinate;
uniform sampler2D u_Texture;
uniform vec2 u_objD;
uniform int fNumEffects;                   // total number of postprocessing effects

#if NUM_POSTPROCESS>0
uniform int pType[NUM_POSTPROCESS];        // their types.
uniform vec4 pUniforms[2*NUM_POSTPROCESS]; // i-th effect is 2 consecutive vec4's: [2*i], [2*i+1].
                                           //

//////////////////////////////////////////////////////////////////////////////////////////////
// BLUR EFFECT

void blur(out vec4 color)
  {
  color = vec4(0.0);

  float blurSizeH = 1.0 / u_objD.x;
  float blurSizeV = 1.0 / u_objD.y;

  for (int x = -4; x <= 4; x++)
    for (int y = -4; y <= 4; y++)
      color += texture( u_Texture, vec2(vTexCoord.x + x * blurSizeH, vTexCoord.y + y * blurSizeV) ) / 81.0;
  }

#endif

//////////////////////////////////////////////////////////////////////////////////////////////

void main()
  {
  vec4 pixel = texture2D(u_Texture,v_TexCoordinate);

#if NUM_POSTPROCESS>0
  for(int i=0; i<fNumEffects; i++)
    {
    if( pType[i]==BLUR ) blur(pixel);
    }
#endif

  gl_FragColor = pixel;
  }